@@ -4,12 +4,12 @@ import ast
 import tokenize
 import itertools
 import io
-
+import json
 
 try:
-    from pip._vendor import pkg_resources
+    from pip._vendor import pkg_resources  # type: ignore
 except ImportError:
-    import pkg_resources
+    import pkg_resources  # type: ignore
 
 
 if sys.version_info < (3,):
@@ -36,12 +36,12 @@ class DepsReader:
         self.script = script
 
     @classmethod
-    def load(cls, script_path):
-        with io.open(script_path) as stream:
-            return cls(stream.read())
+    def try_read(cls, script_path):
+        results = (subclass._try_read(script_path) for subclass in cls.__subclasses__())
+        return next(filter(None, results), Dependencies())
 
     @classmethod
-    def try_read(cls, script_path):
+    def _try_read(cls, script_path):
         """
         Attempt to load the dependencies from the script,
         but return an empty list if unsuccessful.
@@ -50,7 +50,7 @@ class DepsReader:
             reader = cls.load(script_path)
             return reader.read()
         except Exception:
-            return Dependencies()
+            pass
 
     @classmethod
     def search(cls, params):
@@ -90,6 +90,26 @@ class DepsReader:
         return ast.literal_eval(node.value)
 
 
+class SourceDepsReader(DepsReader):
+    @classmethod
+    def load(cls, script_path):
+        with io.open(script_path) as stream:
+            return cls(stream.read())
+
+
+class NotebookDepsReader(DepsReader):
+    @classmethod
+    def load(cls, script_path):
+        doc = json.load(open(script_path))
+        lines = (
+            line
+            for cell in doc['cells']
+            for line in cell['source'] + ['\n']
+            if cell['cell_type'] == 'code' and not line.startswith('%')
+        )
+        return cls(''.join(lines))
+
+
 def run(cmdline):
     """
     Execute the script as if it had been invoked naturally.
